==> sama-0.1.49-sources.jar: com/stefanosiano/powerful_libraries/sama/utils/SamaInitializer.kt <==
package com.stefanosiano.powerful_libraries.sama.utils

import android.app.Activity
import android.app.Application
import android.os.Bundle
import com.stefanosiano.powerful_libraries.sama.view.SamaActivity
import com.stefanosiano.powerful_libraries.sama.view.SamaIntent

object SamaInitializer {

    /** Initializes the SAMA library */
    fun init(application: Application, defaultYeslabel: Int = android.R.string.yes, defaultNolabel: Int = android.R.string.no) {
        application.registerActivityLifecycleCallbacks(object : Application.ActivityLifecycleCallbacks {
            override fun onActivityPaused(activity: Activity?) {}
            override fun onActivityResumed(activity: Activity?) { setMessages(activity) }
            override fun onActivityStarted(activity: Activity?) {}
            override fun onActivityDestroyed(activity: Activity?) { clearIntent(activity) }
            override fun onActivitySaveInstanceState(activity: Activity?, outState: Bundle?) {}
            override fun onActivityStopped(activity: Activity?) {}
            override fun onActivityCreated(activity: Activity?, savedInstanceState: Bundle?) { setMessages(activity) }
        })

        Messages.defaultYes = defaultYeslabel
        Messages.defaultNo = defaultNolabel
    }

    /** Clears the intent used to start an activity */
    private fun clearIntent(activity: Activity?) = activity?.let { if(it is SamaActivity) SamaIntent.clear("${it.samaIntent.uid} ") }

    /** Sets the current activity on which to show the messages */
    private fun setMessages(activity: Activity?) = activity?.let { Messages.setCurrentActivity(it) }

}

==> sama-0.1.64-sources.jar: com/stefanosiano/powerful_libraries/sama/utils/SamaInitializer.kt <==
package com.stefanosiano.powerful_libraries.sama.utils

import android.app.Activity
import android.app.Application
import android.os.Bundle
import com.stefanosiano.powerful_libraries.sama.view.SamaActivity
import com.stefanosiano.powerful_libraries.sama.view.SamaIntent

object SamaInitializer {

    /** Initializes the SAMA library */
    fun init(application: Application, defaultMessagesTheme: Int? = null, defaultYeslabel: Int = android.R.string.yes, defaultNolabel: Int = android.R.string.no) {

        application.registerActivityLifecycleCallbacks(object : Application.ActivityLifecycleCallbacks {
            override fun onActivityPaused(activity: Activity?) {}
            override fun onActivityResumed(activity: Activity?) { setMessages(activity) }
            override fun onActivityStarted(activity: Activity?) { setMessages(activity) }
            override fun onActivityDestroyed(activity: Activity?) { clearIntent(activity) }
            override fun onActivitySaveInstanceState(activity: Activity?, outState: Bundle?) {}
            override fun onActivityStopped(activity: Activity?) {}
            override fun onActivityCreated(activity: Activity?, savedInstanceState: Bundle?) { setMessages(activity) }
        })

        Msg.defaultTheme = defaultMessagesTheme
        Msg.defaultYes = defaultYeslabel
        Msg.defaultNo = defaultNolabel
    }

    /** Clears the intent used to start an activity */
    private fun clearIntent(activity: Activity?) = activity?.let { if(it is SamaActivity) SamaIntent.clear("${it.samaIntent.uid} ") }

    /** Sets the current activity on which to show the messages */
    private fun setMessages(activity: Activity?) = activity?.let { Msg.setCurrentActivity(it) }

}
